<div align="center">

  <a href="https://v2.nonebot.dev/">
    <img src="https://pic.imgdb.cn/item/64ca75781ddac507ccf21163.webp">

  </a>

_🔼好看吗，好看的话就点个⭐吧，这(~姐姐~)可以给予作者最大的动力哦🔼_

# nonebot-plugin-csornament

_✨ [Nonebot2](https://githubfast.com/nonebot/nonebot2) 插件，拥有您的饰品查询机器人 ✨_

![tip](https://badgen.net/badge/python/3.8+/orange?i)  ![tip](https://badgen.net/badge/windows/10+/green?i)  ![tip](https://badgen.net/badge/ubuntu/20.04+/pink?i)  ![tip](https://badgen.net/badge/windows/10+/green?i) ![tip](https://badgen.net/badge/license/MIT/blue?i) ![tip](https://badgen.net/badge/nonebot/2.0.0rc1+/red?i)


</div>


## 使用方法

### 先安装**nonebot_plugin_csornament**
 nonebot商店安装（推荐，但在审核中）

 ```
 nb plugin install nonebot-plugin-csornament
```
 
 pip安装（推荐）
  
 ```
 pip install nonebot_pluin_csornament
```
 
 此方法需要在入口文件**bot.py**导入
 具体请移步nonebot文档[创建入口文件](https://nonebot.dev/docs/tutorial/application)
 
 ### 使用
 3. 启用此插件，具体请看**nonebot**官网文档
 4. 在入口文件下面的**search_data**目录下添加最新的**data.txt**
 5. 发送 `查询/查/搜索 xxx(或者xxx，xxx) `，然后跟随bot指令即可查询价格。例如：[查询 崭新，火神](www.b.com) 或者 [查火神](www.a.com)

    查询后面的关键词可以是一个，也可以是多个。如果您想搜多个关键词，请用**中文逗号**隔开，**不分英文大小写**

:pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray:
   
  > **！！！！！一定要下载数据集data.txt并放入search_data才可以使用！！！！！**

:pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray::pray:

~小声逼逼~:angry:：数据集打包了跟不上BUFF的更新速度



 ## 附件(包含数据集和源码)
:key:下载：[Release最新版本下载地址](https://githubfast.com/Sydrr0/nonebot-plugin-csornament/releases)


:satellite:QQ：**2562312527**

:mailbox:邮箱：**2562312527@qq.com**

:telephone_receiver:Telegram: **SydrrO**
